@@ -20,7 +20,7 @@ use super::panic_if_null;
 /// If the C string is not a valid UTF-8 string.
 #[must_use]
 #[inline]
-pub unsafe fn ref_str(string: *const c_char) -> Result<&str, Utf8Error> {
+pub unsafe fn ref_str<'a>(string: *const c_char) -> Result<&'a str, Utf8Error> {
     #[cfg(any(feature = "panic-if-null", debug_assertions))]
     panic_if_null(string);
     // CAUTION: this is unsafe
